@@ -91,52 +91,60 @@ class SubscriptionProfile(ControllerExecutionMixin):
 
     def update(
         self,
-        name: str,
-        amount: decimal.Decimal,
-        profile_id: int | str,
-        payment_id: int | str,
-        address_id: int | str,
+        name: str | None = None,
+        amount: decimal.Decimal | None = None,
+        profile_id: int | str | None = None,
+        payment_id: int | str | None = None,
+        address_id: int | str | None = None,
     ) -> None:
         """
         Updates a subscription in Authorizenet.
 
         :param name: A name for the subscription.
-        :type name: :py:obj:`str`
+        :type name: :py:obj:`str` | :py:obj:`None`
         :param amount: An amount of money paid per occurrence of the subscription.
-        :type amount: :py:obj:`~decimal.Decimal`
+        :type amount: :py:obj:`~decimal.Decimal` | :py:obj:`None`
         :param profile_id: An Authorizenet customer profile id.
-        :type profile_id: :py:obj:`int` | :py:obj:`str`
+        :type profile_id: :py:obj:`int` | :py:obj:`str` | :py:obj:`None`
         :param payment_id: An Authorizenet customer payment profile id.
-        :type payment_id: :py:obj:`int` | :py:obj:`str`
+        :type payment_id: :py:obj:`int` | :py:obj:`str` | :py:obj:`None`
         :param address_id: An Authorizenet customer address profile id.
-        :type address_id: :py:obj:`int` | :py:obj:`str`
+        :type address_id: :py:obj:`int` | :py:obj:`str` | :py:obj:`None`
         :raises ControllerExecutionError: If something goes wrong during an Authorizenet API call.
-        :raises ValueError: If ``profile_id`` wasn't a digit.
-        :raises ValueError: If ``payment_id`` wasn't a digit.
-        :raises ValueError: If ``address_id`` wasn't a digit.
-        :raises ValueError: If the Authorizenet API response was not retrieved.
-        :returns: An Authorizenet subscription id.
-        :rtype: :py:obj:`int`
+        :raises ValueError: If no arguments were provided.
+        :raises ValueError: If ``profile_id`` was provided but wasn't a digit.
+        :raises ValueError: If ``payment_id`` was provided but wasn't a digit.
+        :raises ValueError: If ``address_id`` was provided but wasn't a digit.
+        :returns: Nothing.
+        :rtype: :py:obj:`None`
 
         """
-        if isinstance(profile_id, str) and not profile_id.isdigit():
+        if not any([name, amount, profile_id, payment_id, address_id]):
+            raise ValueError("At least one argument is required.")
+        if profile_id and isinstance(profile_id, str) and not profile_id.isdigit():
             raise ValueError(f"'profile_id' must be a digit, got '{profile_id}'.")
-        if isinstance(payment_id, str) and not payment_id.isdigit():
+        if payment_id and isinstance(payment_id, str) and not payment_id.isdigit():
             raise ValueError(f"'payment_id' must be a digit, got '{payment_id}'.")
-        if isinstance(address_id, str) and not address_id.isdigit():
+        if address_id and isinstance(address_id, str) and not address_id.isdigit():
             raise ValueError(f"'address_id' must be a digit, got '{address_id}'.")
 
         subscription: apicontractsv1.ARBSubscriptionType = (
-            apicontractsv1.ARBSubscriptionType(
-                name=name,
-                amount=amount,
-                profile=apicontractsv1.customerProfileIdType(
-                    customerProfileId=str(profile_id),
-                    customerPaymentProfileId=str(payment_id),
-                    customerAddressId=str(address_id),
-                ),
-            )
+            apicontractsv1.ARBSubscriptionType()
         )
+
+        if name:
+            subscription.name = name
+        if amount:
+            subscription.amount = amount
+        if any([profile_id, payment_id, address_id]):
+            profile = apicontractsv1.customerProfileIdType()
+            if profile_id:
+                profile.customerProfileId = profile_id
+            if payment_id:
+                profile.customerPaymentProfileId = payment_id
+            if address_id:
+                profile.customerAddressId = address_id
+
         self._authorizenet_update_subscription(subscription)
 
     @property
